/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jsp.taglib.dev;

import com.squeakysand.jsp.tagext.EnhancedSimpleTagSupport;
import com.squeakysand.jsp.tagext.annotations.JspTag;
import com.squeakysand.jsp.tagext.annotations.JspTagAttribute;
import com.squeakysand.jsp.tagext.annotations.JspTagVariable;

import java.io.IOException;
import java.util.Enumeration;

import javax.servlet.jsp.PageContext;
import javax.servlet.jsp.JspException;
import javax.servlet.jsp.tagext.JspFragment;

@JspTag
public class ServletEnvironmentTag extends EnhancedSimpleTagSupport {

    @JspTagVariable
    private static final String ATTRIBUTE_SCOPE_VARIABLE_NAME = "attributeScope";

    @JspTagVariable
    private static final String ATTRIBUTE_NAME_VARIABLE_NAME = "attributeName";

    @JspTagVariable(variableClass = Object.class)
    private static final String ATTRIBUTE_VALUE_VARIABLE_NAME = "attributeValue";

    private JspFragment attributeHeader;
    private JspFragment attributeDisplay;
    private JspFragment attributeFooter;

    @Override
    public void doTag() throws JspException, IOException {
        setPageAttribute(ATTRIBUTE_SCOPE_VARIABLE_NAME, "APPLICATION");
        getAttributeHeader().invoke(null);
        Enumeration<String> applicationScopeAttributeNames = getJspContext().getAttributeNamesInScope(PageContext.APPLICATION_SCOPE);
        while (applicationScopeAttributeNames.hasMoreElements()) {
            String attributeName = applicationScopeAttributeNames.nextElement();
            Object attributeValue = getApplicationAttribute(attributeName);
            setPageAttribute(ATTRIBUTE_NAME_VARIABLE_NAME, attributeName);
            setPageAttribute(ATTRIBUTE_VALUE_VARIABLE_NAME, attributeValue);
            getAttributeDisplay().invoke(null);
        }
        getAttributeFooter().invoke(null);
    }

    public JspFragment getAttributeDisplay() {
        return attributeDisplay;
    }

    @JspTagAttribute
    public void setAttributeDisplay(JspFragment attributeDisplay) {
        this.attributeDisplay = attributeDisplay;
    }

    public JspFragment getAttributeHeader() {
        return attributeHeader;
    }

    @JspTagAttribute
    public void setAttributeHeader(JspFragment attributeHeader) {
        this.attributeHeader = attributeHeader;
    }

    public JspFragment getAttributeFooter() {
        return attributeFooter;
    }

    @JspTagAttribute
    public void setAttributeFooter(JspFragment attributeFooter) {
        this.attributeFooter = attributeFooter;
    }

}
