/*
 * Copyright 2010-2012 Craig S. Dickson (http://craigsdickson.com)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.squeakysand.jsp.taglib.util;

import com.squeakysand.jsp.tagext.annotations.JspElFunction;

import java.util.Collection;

/**
 * Functions for use in EL expressions.
 * 
 * @author <a href="http://craigsdickson.com">Craig S. Dickson</a>
 */
public class Functions {

    /**
     * Returns the size of a collection for use in an EL expression.
     *
     * @param collection the target collection.
     * @return the size of the target collection, or -1 if the collection was <code>null</code>.
     */
    @JspElFunction
    public static Integer size(Collection<?> collection) {
        int result = -1;
        if (collection != null) {
            result = collection.size();
        }
        return result;
    }

    /**
     * Returns the length of an array for use in an EL expression.
     *
     * @param array the target array.
     * @return the length of the target array, or -1 if the array was <code>null</code>.
     */
    @JspElFunction
    public static Integer length(String[] array) {
        int result = -1;
        if (array != null) {
            result = array.length;
        }
        return result;
    }

}
